@@ -55,12 +55,7 @@ $setupnotempty = 0;
 $useFormSetup = 1;
 
 if (!class_exists('FormSetup')) {
-	// For retrocompatibility Dolibarr < 16.0
-	if (floatval(DOL_VERSION) < 16.0 && !class_exists('FormSetup')) {
-		require_once __DIR__.'/../backport/v16/core/class/html.formsetup.class.php';
-	} else {
-		require_once DOL_DOCUMENT_ROOT.'/core/class/html.formsetup.class.php';
-	}
+	require_once DOL_DOCUMENT_ROOT.'/core/class/html.formsetup.class.php';
 }
 
 $formSetup = new FormSetup($db);
@@ -102,7 +97,9 @@ if ($action == 'updateMask') {
 	$tmpobject->initAsSpecimen();
 
 	// Search template files
-	$file = ''; $classname = ''; $filefound = 0;
+	$file = '';
+	$classname = '';
+	$filefound = 0;
 	$dirmodels = array_merge(array('/'), (array) $conf->modules_parts['models']);
 	foreach ($dirmodels as $reldir) {
 		$file = dol_buildpath($reldir."core/modules/webhook/doc/pdf_".$modele."_".strtolower($tmpobjectkey).".modules.php", 0);
@@ -145,7 +142,7 @@ if ($action == 'updateMask') {
 		$tmpobjectkey = GETPOST('object');
 		if (!empty($tmpobjectkey)) {
 			$constforval = 'WEBHOOK_'.strtoupper($tmpobjectkey).'_ADDON_PDF';
-			if ($conf->global->$constforval == "$value") {
+			if (getDolGlobalString($constforval) == "$value") {
 				dolibarr_del_const($db, $constforval, $conf->entity);
 			}
 		}
@@ -222,14 +219,14 @@ if ($action == 'edit') {
 
 				if ($val['type'] == 'textarea') {
 					print '<textarea class="flat" name="'.$constname.'" id="'.$constname.'" cols="50" rows="5" wrap="soft">' . "\n";
-					print $conf->global->{$constname};
+					print getDolGlobalString($constname);
 					print "</textarea>\n";
 				} elseif ($val['type']== 'html') {
 					require_once DOL_DOCUMENT_ROOT . '/core/class/doleditor.class.php';
-					$doleditor = new DolEditor($constname, $conf->global->{$constname}, '', 160, 'dolibarr_notes', '', false, false, $conf->fckeditor->enabled, ROWS_5, '90%');
+					$doleditor = new DolEditor($constname, getDolGlobalString($constname), '', 160, 'dolibarr_notes', '', false, false, isModEnabled('fckeditor'), ROWS_5, '90%');
 					$doleditor->Create();
 				} elseif ($val['type'] == 'yesno') {
-					print $form->selectyesno($constname, $conf->global->{$constname}, 1);
+					print $form->selectyesno($constname, getDolGlobalString($constname), 1);
 				} elseif (preg_match('/emailtemplate:/', $val['type'])) {
 					include_once DOL_DOCUMENT_ROOT . '/core/class/html.formmail.class.php';
 					$formmail = new FormMail($db);
@@ -249,7 +246,7 @@ if ($action == 'edit') {
 							$arrayofmessagename[$modelmail->id] = $langs->trans(preg_replace('/\(|\)/', '', $modelmail->label)) . $moreonlabel;
 						}
 					}
-					print $form->selectarray($constname, $arrayofmessagename, $conf->global->{$constname}, 'None', 0, 0, '', 0, 0, 0, '', '', 1);
+					print $form->selectarray($constname, $arrayofmessagename, getDolGlobalString($constname), 'None', 0, 0, '', 0, 0, 0, '', '', 1);
 				} elseif (preg_match('/category:/', $val['type'])) {
 					require_once DOL_DOCUMENT_ROOT.'/categories/class/categorie.class.php';
 					require_once DOL_DOCUMENT_ROOT.'/core/class/html.formother.class.php';
@@ -257,13 +254,13 @@ if ($action == 'edit') {
 
 					$tmp = explode(':', $val['type']);
 					print img_picto('', 'category', 'class="pictofixedwidth"');
-					print $formother->select_categories($tmp[1],  $conf->global->{$constname}, $constname, 0, $langs->trans('CustomersProspectsCategoriesShort'));
+					print $formother->select_categories($tmp[1], getDolGlobalString($constname), $constname, 0, $langs->trans('CustomersProspectsCategoriesShort'));
 				} elseif (preg_match('/thirdparty_type/', $val['type'])) {
 					require_once DOL_DOCUMENT_ROOT.'/core/class/html.formcompany.class.php';
 					$formcompany = new FormCompany($db);
-					print $formcompany->selectProspectCustomerType($conf->global->{$constname}, $constname);
+					print $formcompany->selectProspectCustomerType(getDolGlobalString($constname), $constname);
 				} elseif ($val['type'] == 'securekey') {
-					print '<input required="required" type="text" class="flat" id="'.$constname.'" name="'.$constname.'" value="'.(GETPOST($constname, 'alpha') ?GETPOST($constname, 'alpha') : $conf->global->{$constname}).'" size="40">';
+					print '<input required="required" type="text" class="flat" id="'.$constname.'" name="'.$constname.'" value="'.(GETPOST($constname, 'alpha') ? GETPOST($constname, 'alpha') : getDolGlobalString($constname)).'" size="40">';
 					if (!empty($conf->use_javascript_ajax)) {
 						print '&nbsp;'.img_picto($langs->trans('Generate'), 'refresh', 'id="generate_token'.$constname.'" class="linkobject"');
 					}
@@ -273,11 +270,11 @@ if ($action == 'edit') {
 					print dolJSToSetRandomPassword($constname, 'generate_token'.$constname);
 				} elseif ($val['type'] == 'product') {
 					if (isModEnabled("product") || isModEnabled("service")) {
-						$selected = (empty($conf->global->$constname) ? '' : $conf->global->$constname);
+						$selected = getDolGlobalString($constname);
 						$form->select_produits($selected, $constname, '', 0);
 					}
 				} else {
-					print '<input name="'.$constname.'"  class="flat '.(empty($val['css']) ? 'minwidth200' : $val['css']).'" value="'.$conf->global->{$constname}.'">';
+					print '<input name="'.$constname.'"  class="flat '.(empty($val['css']) ? 'minwidth200' : $val['css']).'" value="'.getDolGlobalString($constname).'">';
 				}
 				print '</td></tr>';
 			}
@@ -311,9 +308,9 @@ if ($action == 'edit') {
 					print '</td><td>';
 
 					if ($val['type'] == 'textarea') {
-						print dol_nl2br($conf->global->{$constname});
+						print dol_nl2br(getDolGlobalString($constname));
 					} elseif ($val['type']== 'html') {
-						print  $conf->global->{$constname};
+						print getDolGlobalString($constname);
 					} elseif ($val['type'] == 'yesno') {
 						print ajax_constantonoff($constname);
 					} elseif (preg_match('/emailtemplate:/', $val['type'])) {
@@ -322,17 +319,17 @@ if ($action == 'edit') {
 
 						$tmp = explode(':', $val['type']);
 
-						$template = $formmail->getEMailTemplate($db, $tmp[1], $user, $langs, $conf->global->{$constname});
+						$template = $formmail->getEMailTemplate($db, $tmp[1], $user, $langs, getDolGlobalString($constname));
 						if ($template<0) {
 							setEventMessages(null, $formmail->errors, 'errors');
 						}
 						print $langs->trans($template->label);
 					} elseif (preg_match('/category:/', $val['type'])) {
 						$c = new Categorie($db);
-						$result = $c->fetch($conf->global->{$constname});
+						$result = $c->fetch(getDolGlobalString($constname));
 						if ($result < 0) {
 							setEventMessages(null, $c->errors, 'errors');
-						} elseif ($result > 0 ) {
+						} elseif ($result > 0) {
 							$ways = $c->print_all_ways(' &gt;&gt; ', 'none', 0, 1); // $ways[0] = "ccc2 >> ccc2a >> ccc2a1" with html formated text
 							$toprint = array();
 							foreach ($ways as $way) {
@@ -341,25 +338,25 @@ if ($action == 'edit') {
 							print '<div class="select2-container-multi-dolibarr" style="width: 90%;"><ul class="select2-choices-dolibarr">' . implode(' ', $toprint) . '</ul></div>';
 						}
 					} elseif (preg_match('/thirdparty_type/', $val['type'])) {
-						if ($conf->global->{$constname}==2) {
+						if (getDolGlobalInt($constname)==2) {
 							print $langs->trans("Prospect");
-						} elseif ($conf->global->{$constname}==3) {
+						} elseif (getDolGlobalInt($constname)==3) {
 							print $langs->trans("ProspectCustomer");
-						} elseif ($conf->global->{$constname}==1) {
+						} elseif (getDolGlobalInt($constname)==1) {
 							print $langs->trans("Customer");
-						} elseif ($conf->global->{$constname}==0) {
+						} elseif (getDolGlobalInt($constname)==0) {
 							print $langs->trans("NorProspectNorCustomer");
 						}
 					} elseif ($val['type'] == 'product') {
 						$product = new Product($db);
-						$resprod = $product->fetch($conf->global->{$constname});
+						$resprod = $product->fetch(getDolGlobalInt($constname));
 						if ($resprod > 0) {
 							print $product->ref;
 						} elseif ($resprod < 0) {
 							setEventMessages(null, $object->errors, "errors");
 						}
 					} else {
-						print $conf->global->{$constname};
+						print getDolGlobalString($constname);
 					}
 					print '</td></tr>';
 				}
@@ -421,10 +418,10 @@ foreach ($myTmpObjects as $myTmpObjectKey => $myTmpObjectArray) {
 							$module = new $file($db);
 
 							// Show modules according to features level
-							if ($module->version == 'development' && $conf->global->MAIN_FEATURES_LEVEL < 2) {
+							if ($module->version == 'development' && getDolGlobalInt('MAIN_FEATURES_LEVEL') < 2) {
 								continue;
 							}
-							if ($module->version == 'experimental' && $conf->global->MAIN_FEATURES_LEVEL < 1) {
+							if ($module->version == 'experimental' && getDolGlobalInt('MAIN_FEATURES_LEVEL') < 1) {
 								continue;
 							}
 
@@ -432,7 +429,7 @@ foreach ($myTmpObjects as $myTmpObjectKey => $myTmpObjectArray) {
 								dol_include_once('/'.$moduledir.'/class/'.strtolower($myTmpObjectKey).'.class.php');
 
 								print '<tr class="oddeven"><td>'.$module->name."</td><td>\n";
-								print $module->info();
+								print $module->info($langs);
 								print '</td>';
 
 								// Show example of numbering model
@@ -450,7 +447,7 @@ foreach ($myTmpObjects as $myTmpObjectKey => $myTmpObjectArray) {
 
 								print '<td class="center">';
 								$constforvar = 'WEBHOOK_'.strtoupper($myTmpObjectKey).'_ADDON';
-								if ($conf->global->$constforvar == $file) {
+								if (getDolGlobalString($constforvar) == $file) {
 									print img_picto($langs->trans("Activated"), 'switch_on');
 								} else {
 									print '<a href="'.$_SERVER["PHP_SELF"].'?action=setmod&token='.newToken().'&object='.strtolower($myTmpObjectKey).'&value='.urlencode($file).'">';
@@ -558,16 +555,16 @@ foreach ($myTmpObjects as $myTmpObjectKey => $myTmpObjectArray) {
 									$module = new $classname($db);
 
 									$modulequalified = 1;
-									if ($module->version == 'development' && $conf->global->MAIN_FEATURES_LEVEL < 2) {
+									if ($module->version == 'development' && getDolGlobalInt('MAIN_FEATURES_LEVEL') < 2) {
 										$modulequalified = 0;
 									}
-									if ($module->version == 'experimental' && $conf->global->MAIN_FEATURES_LEVEL < 1) {
+									if ($module->version == 'experimental' && getDolGlobalInt('MAIN_FEATURES_LEVEL') < 1) {
 										$modulequalified = 0;
 									}
 
 									if ($modulequalified) {
 										print '<tr class="oddeven"><td width="100">';
-										print (empty($module->name) ? $name : $module->name);
+										print(empty($module->name) ? $name : $module->name);
 										print "</td><td>\n";
 										if (method_exists($module, 'info')) {
 											print $module->info($langs);
@@ -592,7 +589,7 @@ foreach ($myTmpObjects as $myTmpObjectKey => $myTmpObjectArray) {
 										// Default
 										print '<td class="center">';
 										$constforvar = 'WEBHOOK_'.strtoupper($myTmpObjectKey).'_ADDON';
-										if ($conf->global->$constforvar == $name) {
+										if (getDolGlobalString($constforvar) == $name) {
 											//print img_picto($langs->trans("Default"), 'on');
 											// Even if choice is the default value, we allow to disable it. Replace this with previous line if you need to disable unset
 											print '<a href="'.$_SERVER["PHP_SELF"].'?action=unsetdoc&token='.newToken().'&object='.urlencode(strtolower($myTmpObjectKey)).'&value='.urlencode($name).'&scan_dir='.urlencode($module->scandir).'&label='.urlencode($module->name).'&amp;type='.urlencode($type).'" alt="'.$langs->trans("Disable").'">'.img_picto($langs->trans("Enabled"), 'on').'</a>';
