@@ -1,6 +1,6 @@
 <?php
 /* Copyright (C) 2015   Jean-François Ferry     <jfefe@aternatik.fr>
- * Copyright (C) 2020   Thibault FOUCART     	<support@ptibogxiv.net>
+ * Copyright (C) 2020   Thibault FOUCART		<support@ptibogxiv.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ class Invoices extends DolibarrApi
 	 *
 	 * @var array   $FIELDS     Mandatory fields, checked when create and update object
 	 */
-	static $FIELDS = array(
+	public static $FIELDS = array(
 		'socid',
 	);
 
@@ -65,11 +65,11 @@ class Invoices extends DolibarrApi
 	 *
 	 * Return an array with invoice informations
 	 *
-	 * @param 	int 	$id           ID of invoice
-	 * @param   int     $contact_list 0:Return array contains all properties, 1:Return array contains just id, -1: Do not return contacts/adddesses
-	 * @return 	array|mixed data without useless information
+	 * @param	int		$id				ID of invoice
+	 * @param   int     $contact_list	0:Return array contains all properties, 1:Return array contains just id, -1: Do not return contacts/adddesses
+	 * @return	Object					Object with cleaned properties
 	 *
-	 * @throws 	RestException
+	 * @throws	RestException
 	 */
 	public function get($id, $contact_list = 1)
 	{
@@ -81,13 +81,13 @@ class Invoices extends DolibarrApi
 	 *
 	 * Return an array with invoice informations
 	 *
-	 * @param       string		$ref			Ref of object
-	 * @param       int         $contact_list  0: Returned array of contacts/addresses contains all properties, 1: Return array contains just id, -1: Do not return contacts/adddesses
-	 * @return 	array|mixed data without useless information
+	 * @param   string		$ref			Ref of object
+	 * @param   int         $contact_list	0: Returned array of contacts/addresses contains all properties, 1: Return array contains just id, -1: Do not return contacts/adddesses
+	 * @return	Object						Object with cleaned properties
 	 *
 	 * @url GET    ref/{ref}
 	 *
-	 * @throws 	RestException
+	 * @throws	RestException
 	 */
 	public function getByRef($ref, $contact_list = 1)
 	{
@@ -99,13 +99,13 @@ class Invoices extends DolibarrApi
 	 *
 	 * Return an array with invoice informations
 	 *
-	 * @param       string		$ref_ext			External reference of object
-	 * @param       int         $contact_list  0: Returned array of contacts/addresses contains all properties, 1: Return array contains just id, -1: Do not return contacts/adddesses
-	 * @return 	array|mixed data without useless information
+	 * @param   string		$ref_ext		External reference of object
+	 * @param   int         $contact_list	0: Returned array of contacts/addresses contains all properties, 1: Return array contains just id, -1: Do not return contacts/adddesses
+	 * @return	Object						Object with cleaned properties
 	 *
 	 * @url GET    ref_ext/{ref_ext}
 	 *
-	 * @throws 	RestException
+	 * @throws	RestException
 	 */
 	public function getByRefExt($ref_ext, $contact_list = 1)
 	{
@@ -117,17 +117,17 @@ class Invoices extends DolibarrApi
 	 *
 	 * Return an array with invoice informations
 	 *
-	 * @param       int         $id            	ID of order
-	 * @param		string		$ref			Ref of object
-	 * @param		string		$ref_ext		External reference of object
-	 * @param       int         $contact_list  	0: Returned array of contacts/addresses contains all properties, 1: Return array contains just id, -1: Do not return contacts/adddesses
-	 * @return 	array|mixed data without useless information
+	 * @param   int         $id				ID of order
+	 * @param	string		$ref			Ref of object
+	 * @param	string		$ref_ext		External reference of object
+	 * @param   int         $contact_list	0: Returned array of contacts/addresses contains all properties, 1: Return array contains just id, -1: Do not return contacts/adddesses
+	 * @return	Object						Object with cleaned properties
 	 *
-	 * @throws 	RestException
+	 * @throws	RestException
 	 */
 	private function _fetch($id, $ref = '', $ref_ext = '', $contact_list = 1)
 	{
-		if (!DolibarrApiAccess::$user->rights->facture->lire) {
+		if (!DolibarrApiAccess::$user->hasRight('facture', 'lire')) {
 			throw new RestException(401);
 		}
 
@@ -164,23 +164,24 @@ class Invoices extends DolibarrApi
 	 *
 	 * Get a list of invoices
 	 *
-	 * @param string	$sortfield	      Sort field
-	 * @param string	$sortorder	      Sort order
-	 * @param int		$limit		      Limit for list
-	 * @param int		$page		      Page number
-	 * @param string   	$thirdparty_ids	  Thirdparty ids to filter orders of (example '1' or '1,2,3') {@pattern /^[0-9,]*$/i}
-	 * @param string	$status		      Filter by invoice status : draft | unpaid | paid | cancelled
+	 * @param string	$sortfield		  Sort field
+	 * @param string	$sortorder		  Sort order
+	 * @param int		$limit			  Limit for list
+	 * @param int		$page			  Page number
+	 * @param string	$thirdparty_ids	  Thirdparty ids to filter orders of (example '1' or '1,2,3') {@pattern /^[0-9,]*$/i}
+	 * @param string	$status			  Filter by invoice status : draft | unpaid | paid | cancelled
 	 * @param string    $sqlfilters       Other criteria to filter answers separated by a comma. Syntax example "(t.ref:like:'SO-%') and (t.date_creation:<:'20160101')"
+	 * @param string    $properties	Restrict the data returned to theses properties. Ignored if empty. Comma separated list of properties names
 	 * @return array                      Array of invoice objects
 	 *
 	 * @throws RestException 404 Not found
 	 * @throws RestException 503 Error
 	 */
-	public function index($sortfield = "t.rowid", $sortorder = 'ASC', $limit = 100, $page = 0, $thirdparty_ids = '', $status = '', $sqlfilters = '')
+	public function index($sortfield = "t.rowid", $sortorder = 'ASC', $limit = 100, $page = 0, $thirdparty_ids = '', $status = '', $sqlfilters = '', $properties = '')
 	{
 		global $db, $conf;
 
-		if (!DolibarrApiAccess::$user->rights->facture->lire) {
+		if (!DolibarrApiAccess::$user->hasRight('facture', 'lire')) {
 			throw new RestException(401);
 		}
 
@@ -199,7 +200,7 @@ class Invoices extends DolibarrApi
 		if ((!DolibarrApiAccess::$user->rights->societe->client->voir && !$socids) || $search_sale > 0) {
 			$sql .= ", sc.fk_soc, sc.fk_user"; // We need these fields in order to filter by sale (including the case where the user can only see his prospects)
 		}
-		$sql .= " FROM ".MAIN_DB_PREFIX."facture as t";
+		$sql .= " FROM ".MAIN_DB_PREFIX."facture AS t LEFT JOIN ".MAIN_DB_PREFIX."facture_extrafields AS ef ON (ef.fk_object = t.rowid)"; // Modification VMR Global Solutions to include extrafields as search parameters in the API GET call, so we will be able to filter on extrafields
 
 		if ((!DolibarrApiAccess::$user->rights->societe->client->voir && !$socids) || $search_sale > 0) {
 			$sql .= ", ".MAIN_DB_PREFIX."societe_commerciaux as sc"; // We need this table joined to the select in order to filter by sale
@@ -273,16 +274,14 @@ class Invoices extends DolibarrApi
 					if (is_array($tmparray)) {
 						$invoice_static->contacts_ids = $tmparray;
 					}
-					$obj_ret[] = $this->_cleanObjectDatas($invoice_static);
+					$obj_ret[] = $this->_filterObjectProperties($this->_cleanObjectDatas($invoice_static), $properties);
 				}
 				$i++;
 			}
 		} else {
 			throw new RestException(503, 'Error when retrieve invoice list : '.$this->db->lasterror());
 		}
-		if (!count($obj_ret)) {
-			throw new RestException(404, 'No invoice found');
-		}
+
 		return $obj_ret;
 	}
 
@@ -301,6 +300,12 @@ class Invoices extends DolibarrApi
 		$result = $this->_validate($request_data);
 
 		foreach ($request_data as $field => $value) {
+			if ($field === 'caller') {
+				// Add a mention of caller so on trigger called after action, we can filter to avoid a loop if we try to sync back again whith the caller
+				$this->invoice->context['caller'] = $request_data['caller'];
+				continue;
+			}
+
 			$this->invoice->$field = $value;
 		}
 		if (!array_key_exists('date', $request_data)) {
@@ -318,29 +323,27 @@ class Invoices extends DolibarrApi
 		if ($this->invoice->create(DolibarrApiAccess::$user, 0, (empty($request_data["date_lim_reglement"]) ? 0 : $request_data["date_lim_reglement"])) < 0) {
 			throw new RestException(500, "Error creating invoice", array_merge(array($this->invoice->error), $this->invoice->errors));
 		}
-		return $this->invoice->id;
+		return ((int) $this->invoice->id);
 	}
 
-	 /**
-	  * Create an invoice using an existing order.
-	  *
-	  *
-	  * @param int   $orderid       Id of the order
-	  *
-	  * @url     POST /createfromorder/{orderid}
-	  *
-	  * @return int
-	  * @throws RestException 400
-	  * @throws RestException 401
-	  * @throws RestException 404
-	  * @throws RestException 405
-	  */
+	/**
+	 * Create an invoice using an existing order.
+	 *
+	 * @param int   $orderid       Id of the order
+	 * @return	Object				Object with cleaned properties
+	 *
+	 * @url     POST /createfromorder/{orderid}
+	 *
+	 * @throws RestException 400
+	 * @throws RestException 401
+	 * @throws RestException 404
+	 * @throws RestException 405
+	 */
 	public function createInvoiceFromOrder($orderid)
 	{
-
 		require_once DOL_DOCUMENT_ROOT.'/commande/class/commande.class.php';
 
-		if (!DolibarrApiAccess::$user->rights->commande->lire) {
+		if (!DolibarrApiAccess::$user->hasRight('commande', 'lire')) {
 			throw new RestException(401);
 		}
 		if (!DolibarrApiAccess::$user->rights->facture->creer) {
@@ -367,15 +370,14 @@ class Invoices extends DolibarrApi
 	/**
 	 * Get lines of an invoice
 	 *
-	 * @param int   $id             Id of invoice
+	 * @param	int   $id				Id of invoice
+	 * @return	array					Array of lines
 	 *
 	 * @url	GET {id}/lines
-	 *
-	 * @return int
 	 */
 	public function getLines($id)
 	{
-		if (!DolibarrApiAccess::$user->rights->facture->lire) {
+		if (!DolibarrApiAccess::$user->hasRight('facture', 'lire')) {
 			throw new RestException(401);
 		}
 
@@ -398,14 +400,13 @@ class Invoices extends DolibarrApi
 	/**
 	 * Update a line to a given invoice
 	 *
-	 * @param int   $id             Id of invoice to update
-	 * @param int   $lineid         Id of line to update
-	 * @param array $request_data   InvoiceLine data
+	 * @param	int   $id             Id of invoice to update
+	 * @param	int   $lineid         Id of line to update
+	 * @param	array $request_data   InvoiceLine data
+	 * @return	Object				  Object with cleaned properties
 	 *
 	 * @url	PUT {id}/lines/{lineid}
 	 *
-	 * @return array
-	 *
 	 * @throws RestException 304
 	 * @throws RestException 401
 	 * @throws RestException 404 Invoice not found
@@ -471,14 +472,13 @@ class Invoices extends DolibarrApi
 	/**
 	 * Add a contact type of given invoice
 	 *
-	 * @param int    $id             Id of invoice to update
-	 * @param int    $contactid      Id of contact to add
-	 * @param string $type           Type of the contact (BILLING, SHIPPING, CUSTOMER)
+	 * @param	int    $id             Id of invoice to update
+	 * @param	int    $contactid      Id of contact to add
+	 * @param	string $type           Type of the contact (BILLING, SHIPPING, CUSTOMER)
+	 * @return	array
 	 *
 	 * @url	POST {id}/contact/{contactid}/{type}
 	 *
-	 * @return int
-	 *
 	 * @throws RestException 401
 	 * @throws RestException 404
 	 */
@@ -508,20 +508,24 @@ class Invoices extends DolibarrApi
 			throw new RestException(500, 'Error when added the contact');
 		}
 
-		return $this->_cleanObjectDatas($this->invoice);
+		return array(
+			'success' => array(
+				'code' => 200,
+				'message' => 'Contact linked to the invoice'
+			)
+		);
 	}
 
 	/**
 	 * Delete a contact type of given invoice
 	 *
-	 * @param int    $id             Id of invoice to update
-	 * @param int    $contactid      Row key of the contact in the array contact_ids.
-	 * @param string $type           Type of the contact (BILLING, SHIPPING, CUSTOMER).
+	 * @param	int    $id             Id of invoice to update
+	 * @param	int    $contactid      Row key of the contact in the array contact_ids.
+	 * @param	string $type           Type of the contact (BILLING, SHIPPING, CUSTOMER).
+	 * @return	Object				   Object with cleaned properties
 	 *
 	 * @url	DELETE {id}/contact/{contactid}/{type}
 	 *
-	 * @return array
-	 *
 	 * @throws RestException 401
 	 * @throws RestException 404
 	 * @throws RestException 500 System error
@@ -560,13 +564,12 @@ class Invoices extends DolibarrApi
 	/**
 	 * Deletes a line of a given invoice
 	 *
-	 * @param int   $id             Id of invoice
-	 * @param int   $lineid 		Id of the line to delete
+	 * @param	int   $id				Id of invoice
+	 * @param	int   $lineid			Id of the line to delete
+	 * @return	Object					Object with cleaned properties
 	 *
 	 * @url     DELETE {id}/lines/{lineid}
 	 *
-	 * @return array
-	 *
 	 * @throws RestException 400
 	 * @throws RestException 401
 	 * @throws RestException 404
@@ -574,7 +577,6 @@ class Invoices extends DolibarrApi
 	 */
 	public function deleteLine($id, $lineid)
 	{
-
 		if (!DolibarrApiAccess::$user->rights->facture->creer) {
 			throw new RestException(401);
 		}
@@ -591,9 +593,7 @@ class Invoices extends DolibarrApi
 			throw new RestException(404, 'Invoice not found');
 		}
 
-		// TODO Check the lineid $lineid is a line of ojbect
-
-		$updateRes = $this->invoice->deleteline($lineid);
+		$updateRes = $this->invoice->deleteline($lineid, $id);
 		if ($updateRes > 0) {
 			return $this->get($id);
 		} else {
@@ -604,9 +604,9 @@ class Invoices extends DolibarrApi
 	/**
 	 * Update invoice
 	 *
-	 * @param int   $id             Id of invoice to update
-	 * @param array $request_data   Datas
-	 * @return int
+	 * @param	int				$id             Id of invoice to update
+	 * @param	array			$request_data   Datas
+	 * @return	Object|false					Object with cleaned properties
 	 */
 	public function put($id, $request_data = null)
 	{
@@ -627,6 +627,12 @@ class Invoices extends DolibarrApi
 			if ($field == 'id') {
 				continue;
 			}
+			if ($field === 'caller') {
+				// Add a mention of caller so on trigger called after action, we can filter to avoid a loop if we try to sync back again whith the caller
+				$this->invoice->context['caller'] = $request_data['caller'];
+				continue;
+			}
+
 			$this->invoice->$field = $value;
 		}
 
@@ -647,12 +653,12 @@ class Invoices extends DolibarrApi
 	/**
 	 * Delete invoice
 	 *
-	 * @param int   $id 	Invoice ID
-	 * @return array
+	 * @param	int		$id		Invoice ID
+	 * @return	array
 	 */
 	public function delete($id)
 	{
-		if (!DolibarrApiAccess::$user->rights->facture->supprimer) {
+		if (!DolibarrApiAccess::$user->hasRight('facture', 'supprimer')) {
 			throw new RestException(401);
 		}
 		$result = $this->invoice->fetch($id);
@@ -753,7 +759,7 @@ class Invoices extends DolibarrApi
 			$request_data->origin,
 			$request_data->origin_id,
 			$request_data->fk_parent_line,
-			empty($request_data->fk_fournprice) ?null:$request_data->fk_fournprice,
+			empty($request_data->fk_fournprice) ? null : $request_data->fk_fournprice,
 			$pa_ht,
 			$request_data->label,
 			$request_data->array_options,
@@ -774,15 +780,15 @@ class Invoices extends DolibarrApi
 	/**
 	 * Adds a contact to an invoice
 	 *
-	 * @param   int 	$id             	Order ID
-	 * @param   int 	$fk_socpeople       	Id of thirdparty contact (if source = 'external') or id of user (if souce = 'internal') to link
-	 * @param   string 	$type_contact           Type of contact (code). Must a code found into table llx_c_type_contact. For example: BILLING
-	 * @param   string  $source             	external=Contact extern (llx_socpeople), internal=Contact intern (llx_user)
+	 * @param   int		$id					Order ID
+	 * @param   int		$fk_socpeople			Id of thirdparty contact (if source = 'external') or id of user (if souce = 'internal') to link
+	 * @param   string	$type_contact           Type of contact (code). Must a code found into table llx_c_type_contact. For example: BILLING
+	 * @param   string  $source					external=Contact extern (llx_socpeople), internal=Contact intern (llx_user)
 	 * @param   int     $notrigger              Disable all triggers
 	 *
 	 * @url POST    {id}/contacts
 	 *
-	 * @return  array
+	 * @return  object
 	 *
 	 * @throws RestException 304
 	 * @throws RestException 401
@@ -828,11 +834,10 @@ class Invoices extends DolibarrApi
 	 *
 	 * @param   int $id             Order ID
 	 * @param   int $idwarehouse    Warehouse ID
+	 * @return	Object				Object with cleaned properties
 	 *
 	 * @url POST    {id}/settodraft
 	 *
-	 * @return  array
-	 *
 	 * @throws RestException 304
 	 * @throws RestException 401
 	 * @throws RestException 404
@@ -886,10 +891,9 @@ class Invoices extends DolibarrApi
 	 * @param   int $id             Invoice ID
 	 * @param   int $idwarehouse    Warehouse ID
 	 * @param   int $notrigger      1=Does not execute triggers, 0= execute triggers
+	 * @return	Object|false		Object with cleaned properties
 	 *
 	 * @url POST    {id}/validate
-	 *
-	 * @return  array
 	 */
 	public function validate($id, $idwarehouse = 0, $notrigger = 0)
 	{
@@ -928,14 +932,13 @@ class Invoices extends DolibarrApi
 	/**
 	 * Sets an invoice as paid
 	 *
-	 * @param   int 	$id            Order ID
-	 * @param   string 	$close_code    Code filled if we classify to 'Paid completely' when payment is not complete (for escompte for example)
-	 * @param   string 	$close_note    Comment defined if we classify to 'Paid' when payment is not complete (for escompte for example)
+	 * @param   int		$id            Order ID
+	 * @param   string	$close_code    Code filled if we classify to 'Paid completely' when payment is not complete (for escompte for example)
+	 * @param   string	$close_note    Comment defined if we classify to 'Paid' when payment is not complete (for escompte for example)
+	 * @return	Object				   Object with cleaned properties
 	 *
 	 * @url POST    {id}/settopaid
 	 *
-	 * @return  array 	An invoice object
-	 *
 	 * @throws RestException 304
 	 * @throws RestException 401
 	 * @throws RestException 404
@@ -980,12 +983,11 @@ class Invoices extends DolibarrApi
 	/**
 	 * Sets an invoice as unpaid
 	 *
-	 * @param   int     $id            Order ID
+	 * @param   int     $id				Order ID
+	 * @return	Object					Object with cleaned properties
 	 *
 	 * @url POST    {id}/settounpaid
 	 *
-	 * @return  array   An invoice object
-	 *
 	 * @throws RestException 304
 	 * @throws RestException 401
 	 * @throws RestException 404
@@ -1030,16 +1032,15 @@ class Invoices extends DolibarrApi
 	 * Get discount from invoice
 	 *
 	 * @param int   $id             Id of invoice
+	 * @return	Object				Object with cleaned properties
 	 *
 	 * @url	GET {id}/discount
-	 *
-	 * @return mixed
 	 */
 	public function getDiscount($id)
 	{
 		require_once DOL_DOCUMENT_ROOT.'/core/class/discount.class.php';
 
-		if (!DolibarrApiAccess::$user->rights->facture->lire) {
+		if (!DolibarrApiAccess::$user->hasRight('facture', 'lire')) {
 			throw new RestException(401);
 		}
 
@@ -1068,10 +1069,10 @@ class Invoices extends DolibarrApi
 	/**
 	 * Create a discount (credit available) for a credit note or a deposit.
 	 *
-	 * @param   int 	$id            Invoice ID
-	 * @url POST    {id}/markAsCreditAvailable
+	 * @param   int		$id				Invoice ID
+	 * @return	Object					Object with cleaned properties
 	 *
-	 * @return  array 	An invoice object
+	 * @url POST    {id}/markAsCreditAvailable
 	 *
 	 * @throws RestException 304
 	 * @throws RestException 401
@@ -1233,26 +1234,24 @@ class Invoices extends DolibarrApi
 		return $this->_cleanObjectDatas($this->invoice);
 	}
 
-	 /**
-	  * Add a discount line into an invoice (as an invoice line) using an existing absolute discount
-	  *
-	  * Note that this consume the discount.
-	  *
-	  * @param int   $id             Id of invoice
-	  * @param int   $discountid     Id of discount
-	  *
-	  * @url     POST {id}/usediscount/{discountid}
-	  *
-	  * @return int
-	  *
-	  * @throws RestException 400
-	  * @throws RestException 401
-	  * @throws RestException 404
-	  * @throws RestException 405
-	  */
+	/**
+	 * Add a discount line into an invoice (as an invoice line) using an existing absolute discount
+	 *
+	 * Note that this consume the discount.
+	 *
+	 * @param int   $id             Id of invoice
+	 * @param int   $discountid     Id of discount
+	 * @return int
+	 *
+	 * @url     POST {id}/usediscount/{discountid}
+	 *
+	 * @throws RestException 400
+	 * @throws RestException 401
+	 * @throws RestException 404
+	 * @throws RestException 405
+	 */
 	public function useDiscount($id, $discountid)
 	{
-
 		if (!DolibarrApiAccess::$user->rights->facture->creer) {
 			throw new RestException(401);
 		}
@@ -1280,26 +1279,24 @@ class Invoices extends DolibarrApi
 		return $result;
 	}
 
-	 /**
-	  * Add an available credit note discount to payments of an existing invoice.
-	  *
-	  *  Note that this consume the credit note.
-	  *
-	  * @param int   $id            Id of invoice
-	  * @param int   $discountid    Id of a discount coming from a credit note
-	  *
-	  * @url     POST {id}/usecreditnote/{discountid}
-	  *
-	  * @return int
-	  *
-	  * @throws RestException 400
-	  * @throws RestException 401
-	  * @throws RestException 404
-	  * @throws RestException 405
-	  */
+	/**
+	 * Add an available credit note discount to payments of an existing invoice.
+	 *
+	 *  Note that this consume the credit note.
+	 *
+	 * @param int   $id            Id of invoice
+	 * @param int   $discountid    Id of a discount coming from a credit note
+	 * @return	int
+	 *
+	 * @url     POST {id}/usecreditnote/{discountid}
+	 *
+	 * @throws RestException 400
+	 * @throws RestException 401
+	 * @throws RestException 404
+	 * @throws RestException 405
+	 */
 	public function useCreditNote($id, $discountid)
 	{
-
 		require_once DOL_DOCUMENT_ROOT.'/core/class/discount.class.php';
 
 		if (!DolibarrApiAccess::$user->rights->facture->creer) {
@@ -1332,12 +1329,11 @@ class Invoices extends DolibarrApi
 	/**
 	 * Get list of payments of a given invoice
 	 *
-	 * @param int   $id             Id of invoice
+	 * @param	int   $id             Id of invoice
+	 * @return	array
 	 *
 	 * @url     GET {id}/payments
 	 *
-	 * @return array
-	 *
 	 * @throws RestException 400
 	 * @throws RestException 401
 	 * @throws RestException 404
@@ -1345,8 +1341,7 @@ class Invoices extends DolibarrApi
 	 */
 	public function getPayments($id)
 	{
-
-		if (!DolibarrApiAccess::$user->rights->facture->lire) {
+		if (!DolibarrApiAccess::$user->hasRight('facture', 'lire')) {
 			throw new RestException(401);
 		}
 		if (empty($id)) {
@@ -1394,8 +1389,6 @@ class Invoices extends DolibarrApi
 	 */
 	public function addPayment($id, $datepaye, $paymentid, $closepaidinvoices, $accountid, $num_payment = '', $comment = '', $chqemetteur = '', $chqbank = '')
 	{
-		global $conf;
-
 		require_once DOL_DOCUMENT_ROOT.'/compta/paiement/class/paiement.class.php';
 
 		if (!DolibarrApiAccess::$user->rights->facture->creer) {
@@ -1439,10 +1432,10 @@ class Invoices extends DolibarrApi
 		// Clean parameters amount if payment is for a credit note
 		if ($this->invoice->type == Facture::TYPE_CREDIT_NOTE) {
 			$resteapayer = price2num($resteapayer, 'MT');
-			$amounts[$id] = -$resteapayer;
+			$amounts[$id] = price2num(-1 * $resteapayer, 'MT');
 			// Multicurrency
 			$newvalue = price2num($this->invoice->multicurrency_total_ttc, 'MT');
-			$multicurrency_amounts[$id] = -$newvalue;
+			$multicurrency_amounts[$id] = price2num(-1 * $newvalue, 'MT');
 		} else {
 			$resteapayer = price2num($resteapayer, 'MT');
 			$amounts[$id] = $resteapayer;
@@ -1508,6 +1501,7 @@ class Invoices extends DolibarrApi
 	 * @url     POST /paymentsdistributed
 	 *
 	 * @return int  Payment ID
+	 *
 	 * @throws RestException 400
 	 * @throws RestException 401
 	 * @throws RestException 403
@@ -1515,8 +1509,6 @@ class Invoices extends DolibarrApi
 	 */
 	public function addPaymentDistributed($arrayofamounts, $datepaye, $paymentid, $closepaidinvoices, $accountid, $num_payment = '', $comment = '', $chqemetteur = '', $chqbank = '', $ref_ext = '', $accepthigherpayment = false)
 	{
-		global $conf;
-
 		require_once DOL_DOCUMENT_ROOT.'/compta/paiement/class/paiement.class.php';
 
 		if (!DolibarrApiAccess::$user->rights->facture->creer) {
@@ -1586,7 +1578,7 @@ class Invoices extends DolibarrApi
 			}
 
 			if ($this->invoice->type == Facture::TYPE_CREDIT_NOTE) {
-				$amount = -$amount;
+				$amount = price2num(-1 * $amount, 'MT');
 			}
 
 			if ($is_multicurrency) {
@@ -1618,7 +1610,7 @@ class Invoices extends DolibarrApi
 		if (isModEnabled("banque")) {
 			$label = '(CustomerInvoicePayment)';
 			if ($paymentobj->paiementcode == 'CHQ' && empty($chqemetteur)) {
-				  throw new RestException(400, 'Emetteur is mandatory when payment code is '.$paymentobj->paiementcode);
+				throw new RestException(400, 'Emetteur is mandatory when payment code is '.$paymentobj->paiementcode);
 			}
 			if ($this->invoice->type == Facture::TYPE_CREDIT_NOTE) {
 				$label = '(CustomerInvoicePaymentBack)'; // Refund of a credit note
@@ -1644,6 +1636,7 @@ class Invoices extends DolibarrApi
 	 * @url     PUT payments/{id}
 	 *
 	 * @return array
+	 *
 	 * @throws RestException 400 Bad parameters
 	 * @throws RestException 401 Not allowed
 	 * @throws RestException 404 Not found
@@ -1707,8 +1700,8 @@ class Invoices extends DolibarrApi
 	/**
 	 * Validate fields before create or update object
 	 *
-	 * @param array|null    $data       Datas to validate
-	 * @return array
+	 * @param	array|null    $data       Datas to validate
+	 * @return	array
 	 *
 	 * @throws RestException
 	 */
@@ -1730,13 +1723,13 @@ class Invoices extends DolibarrApi
 	 *
 	 * Return an array with invoice informations
 	 *
-	 * @param 	int 	$id           	ID of template invoice
-	 * @param   int     $contact_list 	0:Return array contains all properties, 1:Return array contains just id, -1: Do not return contacts/adddesses
-	 * @return 	array|mixed data without useless information
+	 * @param	int		$id				ID of template invoice
+	 * @param   int     $contact_list	0:Return array contains all properties, 1:Return array contains just id, -1: Do not return contacts/adddesses
+	 * @return	Object					Object with cleaned properties
 	 *
 	 * @url GET    templates/{id}
 	 *
-	 * @throws 	RestException
+	 * @throws	RestException
 	 */
 	public function getTemplateInvoice($id, $contact_list = 1)
 	{
@@ -1748,17 +1741,17 @@ class Invoices extends DolibarrApi
 	 *
 	 * Return an array with invoice informations
 	 *
-	 * @param       int         $id            	ID of order
-	 * @param		string		$ref			Ref of object
-	 * @param		string		$ref_ext		External reference of object
-	 * @param       int         $contact_list  	0: Returned array of contacts/addresses contains all properties, 1: Return array contains just id, -1: Do not return contacts/adddesses
-	 * @return 	array|mixed data without useless information
+	 * @param   int         $id				ID of order
+	 * @param	string		$ref			Ref of object
+	 * @param	string		$ref_ext		External reference of object
+	 * @param   int         $contact_list	0: Returned array of contacts/addresses contains all properties, 1: Return array contains just id, -1: Do not return contacts/adddesses
+	 * @return	Object						Object with cleaned properties
 	 *
-	 * @throws 	RestException
+	 * @throws	RestException
 	 */
 	private function _fetchTemplateInvoice($id, $ref = '', $ref_ext = '', $contact_list = 1)
 	{
-		if (!DolibarrApiAccess::$user->rights->facture->lire) {
+		if (!DolibarrApiAccess::$user->hasRight('facture', 'lire')) {
 			throw new RestException(401);
 		}
 
