@@ -3,6 +3,7 @@
  * Copyright (C) 2005-2009	Destailleur Laurent	<eldy@users.sourceforge.net>
  * Copyright (C) 2005-2012	Regis Houssin		<regis.houssin@inodbox.com>
  * Copyright (C) 2017      Ferran Marcet       	 <fmarcet@2byte.es>
+ * Copyright (C) 2023       Christian Foellmann <christian@foellmann.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,70 +48,82 @@ $ref = GETPOST('ref', 'alpha');
 if ($user->socid) {
 	$socid = $user->socid;
 }
-$result = restrictedArea($user, 'contrat', $id);
 
 $object = new Contrat($db);
 
 // Initialize technical object to manage hooks of page. Note that conf->hooks_modules contains array of hook context
-$hookmanager->initHooks(array('contractcard', 'globalcard'));
+$hookmanager->initHooks(array('contractcontactcard', 'globalcard'));
 
-$permissiontoadd   = $user->rights->contrat->creer;     //  Used by the include of actions_addupdatedelete.inc.php and actions_lineupdown.inc.php
+$permissiontoadd   = $user->hasRight('contrat', 'creer');     //  Used by the include of actions_addupdatedelete.inc.php and actions_lineupdown.inc.php
+
+$result = restrictedArea($user, 'contrat', $object->id);
 
 
 /*
  * Actions
  */
 
-if ($action == 'addcontact' && $user->rights->contrat->creer) {
-	$result = $object->fetch($id);
+$parameters = array('id'=>$id);
+$reshook = $hookmanager->executeHooks('doActions', $parameters, $object, $action);
+if ($reshook < 0) {
+	setEventMessages($hookmanager->error, $hookmanager->errors, 'errors');
+}
 
-	if ($result > 0 && $id > 0) {
-		$contactid = (GETPOST('userid') ? GETPOST('userid') : GETPOST('contactid'));
-		$typeid = (GETPOST('typecontact') ? GETPOST('typecontact') : GETPOST('type'));
-		$result = $object->add_contact($contactid, $typeid, GETPOST("source", 'aZ09'));
-	}
+if (empty($reshook)) {
+	// Add new contact
+	if ($action == 'addcontact' && $user->hasRight('contrat', 'creer')) {
+		$result = $object->fetch($id);
 
-	if ($result >= 0) {
-		header("Location: ".$_SERVER['PHP_SELF']."?id=".$object->id);
-		exit;
-	} else {
-		if ($object->error == 'DB_ERROR_RECORD_ALREADY_EXISTS') {
-			$langs->load("errors");
-			$msg = $langs->trans("ErrorThisContactIsAlreadyDefinedAsThisType");
-		} else {
-			$mesg = $object->error;
+		if ($result > 0 && $id > 0) {
+			$contactid = (GETPOST('userid') ? GETPOST('userid') : GETPOST('contactid'));
+			$typeid    = (GETPOST('typecontact') ? GETPOST('typecontact') : GETPOST('type'));
+			$result    = $object->add_contact($contactid, $typeid, GETPOST("source", 'aZ09'));
 		}
 
-		setEventMessages($mesg, null, 'errors');
+		if ($result >= 0) {
+			header("Location: ".$_SERVER['PHP_SELF']."?id=".$object->id);
+			exit;
+		} else {
+			if ($object->error == 'DB_ERROR_RECORD_ALREADY_EXISTS') {
+				$langs->load("errors");
+				$msg = $langs->trans("ErrorThisContactIsAlreadyDefinedAsThisType");
+			} else {
+				$mesg = $object->error;
+			}
+
+			setEventMessages($mesg, null, 'errors');
+		}
+	}
+
+	// Toggle the status of a contact
+	if ($action == 'swapstatut' && $user->hasRight('contrat', 'creer')) {
+		if ($object->fetch($id)) {
+			$result = $object->swapContactStatus(GETPOST('ligne', 'int'));
+		} else {
+			dol_print_error($db, $object->error);
+		}
+	}
+
+	// Delete contact
+	if ($action == 'deletecontact' && $user->hasRight('contrat', 'creer')) {
+		$object->fetch($id);
+		$result = $object->delete_contact(GETPOST("lineid", 'int'));
+
+		if ($result >= 0) {
+			header("Location: ".$_SERVER['PHP_SELF']."?id=".$object->id);
+			exit;
+		}
 	}
 }
 
-// bascule du statut d'un contact
-if ($action == 'swapstatut' && $user->rights->contrat->creer) {
-	if ($object->fetch($id)) {
-		$result = $object->swapContactStatus(GETPOST('ligne', 'int'));
-	} else {
-		dol_print_error($db, $object->error);
-	}
-}
-
-// Delete contact
-if ($action == 'deletecontact' && $user->rights->contrat->creer) {
-	$object->fetch($id);
-	$result = $object->delete_contact(GETPOST("lineid", 'int'));
-
-	if ($result >= 0) {
-		header("Location: ".$_SERVER['PHP_SELF']."?id=".$object->id);
-		exit;
-	}
-}
-
-
 /*
  * View
  */
 
-llxHeader('', $langs->trans("Contract"), "");
+$title = $langs->trans("Contract");
+$help_url = 'EN:Module_Contracts|FR:Module_Contrat';
+
+llxHeader('', $title, $help_url);
 
 $form = new Form($db);
 $formcompany = new FormCompany($db);
@@ -140,7 +153,7 @@ if ($id > 0 || !empty($ref)) {
 
 		$morehtmlref = '';
 		//if (!empty($modCodeContract->code_auto)) {
-			$morehtmlref .= $object->ref;
+		$morehtmlref .= $object->ref;
 		/*} else {
 			$morehtmlref.=$form->editfieldkey("",'ref',$object->ref,0,'string','',0,3);
 			$morehtmlref.=$form->editfieldval("",'ref',$object->ref,0,'string','',0,2);
