@@ -77,7 +77,7 @@ class HookManager
 	 *  Then when a hook executeHooks('aMethod'...) is called, the method aMethod found into class will be executed.
 	 *
 	 *	@param	string[]	$arraycontext	    Array list of searched hooks tab/features. For example: 'thirdpartycard' (for hook methods into page card thirdparty), 'thirdpartydao' (for hook methods into Societe), ...
-	 *	@return	int							    Always 1
+	 *	@return	int								0 or 1
 	 */
 	public function initHooks($arraycontext)
 	{
@@ -85,7 +85,7 @@ class HookManager
 
 		// Test if there is hooks to manage
 		if (!is_array($conf->modules_parts['hooks']) || empty($conf->modules_parts['hooks'])) {
-			return;
+			return 0;
 		}
 
 		// For backward compatibility
@@ -148,101 +148,67 @@ class HookManager
 	 *  @param		array	$parameters		Array of parameters
 	 *  @param		Object	$object			Object to use hooks on
 	 *  @param		string	$action			Action code on calling page ('create', 'edit', 'view', 'add', 'update', 'delete'...)
-	 *  @return		mixed					For 'addreplace' hooks (doActions, formConfirm, formObjectOptions, pdf_xxx,...): 	Return 0 if we want to keep standard actions, >0 if we want to stop/replace standard actions, <0 if KO. Things to print are returned into ->resprints and set into ->resPrint. Things to return are returned into ->results by hook and set into ->resArray for caller.
+	 *  @return		int						For 'addreplace' hooks (doActions, formConfirm, formObjectOptions, pdf_xxx,...): 	Return 0 if we want to keep standard actions, >0 if we want to stop/replace standard actions, <0 if KO. Things to print are returned into ->resprints and set into ->resPrint. Things to return are returned into ->results by hook and set into ->resArray for caller.
 	 *                                      For 'output' hooks (printLeftBlock, formAddObjectLine, formBuilddocOptions, ...):	Return 0 if we want to keep standard actions, >0 uf we want to stop/replace standard actions (at least one > 0 and replacement will be done), <0 if KO. Things to print are returned into ->resprints and set into ->resPrint. Things to return are returned into ->results by hook and set into ->resArray for caller.
 	 *                                      All types can also return some values into an array ->results that will be finaly merged into this->resArray for caller.
 	 *                                      $this->error or this->errors are also defined by class called by this function if error.
 	 */
-	public function executeHooks($method, $parameters = array(), &$object = '', &$action = '')
+	public function executeHooks($method, $parameters = array(), &$object = null, &$action = '')
 	{
 		if (!is_array($this->hooks) || empty($this->hooks)) {
 			return 0; // No hook available, do nothing.
 		}
+		if (!is_array($parameters)) {
+			dol_syslog('executeHooks was called with a non array $parameters. Surely a bug.', LOG_WARNING);
+			$parameters = array();
+		}
 
 		$parameters['context'] = join(':', $this->contextarray);
 		//dol_syslog(get_class($this).'::executeHooks method='.$method." action=".$action." context=".$parameters['context']);
 
 		// Define type of hook ('output' or 'addreplace').
-		// TODO Remove hooks with type 'output' (exemple getNomUrl). All hooks must be converted into 'addreplace' hooks.
-		$hooktype = 'output';
-		if (in_array(
-			$method,
-			array(
-				'addCalendarChoice',
-				'addCalendarView',
-				'addMoreActionsButtons',
-				'addMoreMassActions',
-				'addSearchEntry',
-				'addStatisticLine',
-				'addSectionECMAuto',
-				'checkSecureAccess',
-				'createDictionaryFieldlist',
-				'editDictionaryFieldlist',
-				'getFormMail',
-				'deleteFile',
-				'doActions',
-				'doMassActions',
-				'formatEvent',
-				'formConfirm',
-				'formCreateThirdpartyOptions',
-				'formObjectOptions',
-				'formattachOptions',
-				'formBuilddocLineOptions',
-				'formatNotificationMessage',
-				'formConfirm',
-				'getAccessForbiddenMessage',
-				'getDirList',
-				'hookGetEntity',
-				'getFormMail',
-				'getFormatedCustomerRef',
-				'getFormatedSupplierRef',
-				'getIdProfUrl',
-				'getInputIdProf',
-				'menuDropdownQuickaddItems',
-				'menuLeftMenuItems',
-				'moveUploadedFile',
-				'moreHtmlStatus',
-				'pdf_build_address',
-				'pdf_writelinedesc',
-				'pdf_getlinenum',
-				'pdf_getlineref',
-				'pdf_getlineref_supplier',
-				'pdf_getlinevatrate',
-				'pdf_getlineupexcltax',
-				'pdf_getlineupwithtax',
-				'pdf_getlineqty',
-				'pdf_getlineqty_asked',
-				'pdf_getlineqty_shipped',
-				'pdf_getlineqty_keeptoship',
-				'pdf_getlineunit',
-				'pdf_getlineremisepercent',
-				'pdf_getlineprogress',
-				'pdf_getlinetotalexcltax',
-				'pdf_getlinetotalwithtax',
-				'paymentsupplierinvoices',
-				'printAddress',
-				'printEmail',
-				'printSearchForm',
-				'printTabsHead',
-				'printObjectLine',
-				'printObjectSubLine',
-				'restrictedArea',
-				'sendMail',
-				'sendMailAfter',
-				'showOptionals',
-				'showLinkToObjectBlock',
-				'setContentSecurityPolicy',
-				'setHtmlTitle',
-				'completeTabsHead',
-				'formDolBanner',
-				'displayMarginInfos',
-				)
-		)) {
-			$hooktype = 'addreplace';
+		$hooktype = 'addreplace';
+		// TODO Remove hooks with type 'output' (exemple createFrom). All hooks must be converted into 'addreplace' hooks.
+		if (in_array($method, array(
+			'createFrom',
+			'dashboardAccountancy',
+			'dashboardActivities',
+			'dashboardCommercials',
+			'dashboardContracts',
+			'dashboardDonation',
+			'dashboardEmailings',
+			'dashboardExpenseReport',
+			'dashboardHRM',
+			'dashboardInterventions',
+			'dashboardMRP',
+			'dashboardMembers',
+			'dashboardOpensurvey',
+			'dashboardOrders',
+			'dashboardOrdersSuppliers',
+			'dashboardProductServices',
+			'dashboardProjects',
+			'dashboardPropals',
+			'dashboardSpecialBills',
+			'dashboardSupplierProposal',
+			'dashboardThirdparties',
+			'dashboardTickets',
+			'dashboardUsersGroups',
+			'dashboardWarehouse',
+			'dashboardWarehouseReceptions',
+			'dashboardWarehouseSendings',
+			'insertExtraHeader',
+			'insertExtraFooter',
+			'printLeftBlock',
+			'formAddObjectLine',
+			'formBuilddocOptions',
+			'showSocinfoOnPrint'
+		))) {
+			$hooktype = 'output';
 		}
 
 		// Init return properties
-		$this->resPrint = '';
+		$localResPrint = '';
+		$localResArray = array();
 		$this->resArray = array();
 		$this->resNbOfHooks = 0;
 
@@ -276,8 +242,8 @@ class HookManager
 					$actionclassinstance->error = 0;
 					$actionclassinstance->errors = array();
 
-					if (getDolGlobalInt('MAIN_DEBUG_SHOW_EACH_QUALIFIED_HOOK_CALL') >= 2) {
-						// This his too much verbose, enabled in develop only
+					if (getDolGlobalInt('MAIN_HOOK_DEBUG')) {
+						// This his too much verbose, enabled if const enabled only
 						dol_syslog(get_class($this)."::executeHooks Qualified hook found (hooktype=".$hooktype."). We call method ".get_class($actionclassinstance).'->'.$method.", context=".$context.", module=".$module.", action=".$action.((is_object($object) && property_exists($object, 'id')) ? ', object id='.$object->id : '').((is_object($object) && property_exists($object, 'element')) ? ', object element='.$object->element : ''), LOG_DEBUG);
 					}
 
@@ -298,16 +264,16 @@ class HookManager
 
 						if (isset($actionclassinstance->results) && is_array($actionclassinstance->results)) {
 							if ($resactiontmp > 0) {
-								$this->resArray = $actionclassinstance->results;
+								$localResArray = $actionclassinstance->results;
 							} else {
-								$this->resArray = array_merge($this->resArray, $actionclassinstance->results);
+								$localResArray = array_merge($localResArray, $actionclassinstance->results);
 							}
 						}
 						if (!empty($actionclassinstance->resprints)) {
 							if ($resactiontmp > 0) {
-								$this->resPrint = $actionclassinstance->resprints;
+								$localResPrint = $actionclassinstance->resprints;
 							} else {
-								$this->resPrint .= $actionclassinstance->resprints;
+								$localResPrint .= $actionclassinstance->resprints;
 							}
 						}
 					} else {
@@ -318,15 +284,18 @@ class HookManager
 							continue;
 						}
 
-						//dol_syslog("Call method ".$method." of class ".get_class($actionclassinstance).", module=".$module.", hooktype=".$hooktype, LOG_DEBUG);
+						if (getDolGlobalInt('MAIN_HOOK_DEBUG')) {
+							dol_syslog("Call method ".$method." of class ".get_class($actionclassinstance).", module=".$module.", hooktype=".$hooktype, LOG_DEBUG);
+						}
+
 						$resactiontmp = $actionclassinstance->$method($parameters, $object, $action, $this); // $object and $action can be changed by method ($object->id during creation for example or $action to go back to other action for example)
 						$resaction += $resactiontmp;
 
 						if (!empty($actionclassinstance->results) && is_array($actionclassinstance->results)) {
-							$this->resArray = array_merge($this->resArray, $actionclassinstance->results);
+							$localResArray = array_merge($localResArray, $actionclassinstance->results);
 						}
 						if (!empty($actionclassinstance->resprints)) {
-							$this->resPrint .= $actionclassinstance->resprints;
+							$localResPrint .= $actionclassinstance->resprints;
 						}
 						if (is_numeric($resactiontmp) && $resactiontmp < 0) {
 							$error++;
@@ -339,7 +308,7 @@ class HookManager
 						if (!is_array($resactiontmp) && !is_numeric($resactiontmp)) {
 							dol_syslog('Error: Bug into hook '.$method.' of module class '.get_class($actionclassinstance).'. Method must not return a string but an int (0=OK, 1=Replace, -1=KO) and set string into ->resprints', LOG_ERR);
 							if (empty($actionclassinstance->resprints)) {
-								$this->resPrint .= $resactiontmp;
+								$localResPrint .= $resactiontmp;
 							}
 						}
 					}
@@ -352,6 +321,9 @@ class HookManager
 			}
 		}
 
+		$this->resPrint = $localResPrint;
+		$this->resArray = $localResArray;
+
 		return ($error ? -1 : $resaction);
 	}
 }
