@@ -3,8 +3,10 @@
  * Copyright (C) 2005-2011 Regis Houssin        <regis.houssin@inodbox.com>
  * Copyright (C) 2011-2015 Juanjo Menent        <jmenent@2byte.es>
  * Copyright (C) 2017      Ferran Marcet        <fmarcet@2byte.es>
- * Copyright (C) 2018      Charlene Benke       <charlie@patas-monkey.com>
-*
+ * Copyright (C) 2018-2024 Charlene Benke       <charlene@patas-monkey.com>
+ * Copyright (C) 2024	     MDW					        <mdeweerd@users.noreply.github.com>
+ * Copyright (C) 2024      Frédéric France      <frederic.france@free.fr>
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
@@ -34,31 +36,32 @@
 function get_tz_array()
 {
 	$tzarray = array(
-		-11=>"Pacific/Midway",
-		-10=>"Pacific/Fakaofo",
-		-9=>"America/Anchorage",
-		-8=>"America/Los_Angeles",
-		-7=>"America/Dawson_Creek",
-		-6=>"America/Chicago",
-		-5=>"America/Bogota",
-		-4=>"America/Anguilla",
-		-3=>"America/Araguaina",
-		-2=>"America/Noronha",
-		-1=>"Atlantic/Azores",
-		0=>"Africa/Abidjan",
-		1=>"Europe/Paris",
-		2=>"Europe/Helsinki",
-		3=>"Europe/Moscow",
-		4=>"Asia/Dubai",
-		5=>"Asia/Karachi",
-		6=>"Indian/Chagos",
-		7=>"Asia/Jakarta",
-		8=>"Asia/Hong_Kong",
-		9=>"Asia/Tokyo",
-		10=>"Australia/Sydney",
-		11=>"Pacific/Noumea",
-		12=>"Pacific/Auckland",
-		13=>"Pacific/Enderbury"
+		-11 => "Pacific/Pago_Pago",
+		-10 => "Pacific/Honolulu",
+		-9 => "America/Anchorage",
+		-8 => "America/Los_Angeles",
+		-7 => "America/Dawson_Creek",
+		-6 => "America/Chicago",
+		-5 => "America/Bogota",
+		-4 => "America/Asuncion",
+		-3 => "America/Araguaina",
+		-2 => "America/Noronha",
+		-1 => "Atlantic/Azores",
+		0 => "Europe/London",
+		1 => "Europe/Paris",
+		2 => "Europe/Helsinki",
+		3 => "Europe/Moscow",
+		4 => "Asia/Dubai",
+		5 => "Asia/Karachi",
+		6 => "Indian/Chagos",
+		7 => "Asia/Jakarta",
+		8 => "Asia/Hong_Kong",
+		9 => "Asia/Tokyo",
+		10 => "Australia/Sydney",
+		11 => "Pacific/Noumea",
+		12 => "Pacific/Auckland",
+		13 => "Pacific/Fakaofo",
+		14 => "Pacific/Kiritimati"
 	);
 	return $tzarray;
 }
@@ -117,16 +120,17 @@ function getServerTimeZoneInt($refgmtdate = 'now')
  *  @param      int			$duration_unit      Unit of added delay (d, m, y, w, h, i)
  *  @param      int         $ruleforendofmonth  Change the behavior of PHP over data-interval, 0 or 1
  *  @return     int      			        	New timestamp
+ *  @see convertSecondToTime(), convertTimeToSeconds()
  */
 function dol_time_plus_duree($time, $duration_value, $duration_unit, $ruleforendofmonth = 0)
 {
 	global $conf;
+	if (empty($duration_value)) {
+		return $time;
+	}
 	if ($duration_unit == 's') {
 		return $time + ($duration_value);
 	}
-	if ($duration_value == 0) {
-		return $time;
-	}
 	if ($duration_unit == 'i') {
 		return $time + (60 * $duration_value);
 	}
@@ -158,7 +162,7 @@ function dol_time_plus_duree($time, $duration_value, $duration_unit, $ruleforend
 	}
 
 	$date = new DateTime();
-	if (!empty($conf->global->MAIN_DATE_IN_MEMORY_ARE_GMT)) {
+	if (getDolGlobalString('MAIN_DATE_IN_MEMORY_ARE_GMT')) {
 		$date->setTimezone(new DateTimeZone('UTC'));
 	}
 	$date->setTimestamp($time);
@@ -218,7 +222,8 @@ function convertTime2Seconds($iHours = 0, $iMinutes = 0, $iSeconds = 0)
  *      Can be used to show a duration.
  *
  *    	@param      int		$iSecond		Number of seconds
- *    	@param      string	$format		    Output format ('all': total delay days hour:min like "2 days 12:30",
+ *    	@param      string	$format		    Output format
+ *    										- 'all': total delay days hour:min like "2 days 12:30",
  *                                          - 'allwithouthour': total delay days without hour part like "2 days",
  *                                          - 'allhourmin': total delay with format hours:min like "60:30",
  *                                          - 'allhourminsec': total delay with format hours:min:sec like "60:30:10",
@@ -331,13 +336,27 @@ function convertDurationtoHour($duration_value, $duration_unit)
 {
 	$result = 0;
 
-	if ($duration_unit == 's') $result = $duration_value / 3600;
-	if ($duration_unit == 'i') $result = $duration_value / 60;
-	if ($duration_unit == 'h') $result = $duration_value;
-	if ($duration_unit == 'd') $result = $duration_value * 24;
-	if ($duration_unit == 'w') $result = $duration_value * 24 * 7;
-	if ($duration_unit == 'm') $result = $duration_value * 730.484;
-	if ($duration_unit == 'y') $result = $duration_value * 365 * 24;
+	if ($duration_unit == 's') {
+		$result = $duration_value / 3600;
+	}
+	if ($duration_unit == 'i') {
+		$result = $duration_value / 60;
+	}
+	if ($duration_unit == 'h') {
+		$result = $duration_value;
+	}
+	if ($duration_unit == 'd') {
+		$result = $duration_value * 24;
+	}
+	if ($duration_unit == 'w') {
+		$result = $duration_value * 24 * 7;
+	}
+	if ($duration_unit == 'm') {
+		$result = $duration_value * 730.484;
+	}
+	if ($duration_unit == 'y') {
+		$result = $duration_value * 365 * 24;
+	}
 
 	return $result;
 }
@@ -748,7 +767,7 @@ function num_public_holiday($timestampStart, $timestampEnd, $country_code = '',
 	$nbFerie = 0;
 
 	// Check to ensure we use correct parameters
-	if ((($timestampEnd - $timestampStart) % 86400) != 0) {
+	if (($timestampEnd - $timestampStart) % 86400 != 0) {
 		return 'Error Dates must use same hours and must be GMT dates';
 	}
 
@@ -787,6 +806,7 @@ function num_public_holiday($timestampStart, $timestampEnd, $country_code = '',
 		$sql = "SELECT code, entity, fk_country, dayrule, year, month, day, active";
 		$sql .= " FROM ".MAIN_DB_PREFIX."c_hrm_public_holiday";
 		$sql .= " WHERE active = 1 and fk_country IN (0".($country_id > 0 ? ", ".$country_id : 0).")";
+		$sql .= " AND entity IN (0," .getEntity('holiday') .")";
 
 		$resql = $db->query($sql);
 		if ($resql) {
@@ -877,7 +897,7 @@ function num_public_holiday($timestampStart, $timestampEnd, $country_code = '',
 				// Ascension (thursday)
 			}
 
-			if (in_array('pentecote', $specialdayrule)) {
+			if (in_array('pentecost', $specialdayrule)) {
 				// Calculation of "Pentecote" (49 days after easter day)
 				$date_paques = getGMTEasterDatetime($annee);
 				$date_pentecote = $date_paques + (3600 * 24 * 49);
@@ -929,7 +949,9 @@ function num_public_holiday($timestampStart, $timestampEnd, $country_code = '',
 				$date_1sunsept = strtotime('next thursday', strtotime('next sunday', mktime(0, 0, 0, 9, 1, $annee)));
 				$jour_1sunsept = date("d", $date_1sunsept);
 				$mois_1sunsept = date("m", $date_1sunsept);
-				if ($jour_1sunsept == $jour && $mois_1sunsept == $mois) $ferie=true;
+				if ($jour_1sunsept == $jour && $mois_1sunsept == $mois) {
+					$ferie=true;
+				}
 				// Geneva fast in Switzerland
 			}
 		}
@@ -942,7 +964,7 @@ function num_public_holiday($timestampStart, $timestampEnd, $country_code = '',
 				$jour_semaine = jddayofweek($jour_julien, 0);
 				if ($includefriday) {					//Friday (5), Saturday (6) and Sunday (0)
 					if ($jour_semaine == 5) {
-							$ferie = true;
+						$ferie = true;
 					}
 				}
 				if ($includesaturday) {					//Friday (5), Saturday (6) and Sunday (0)
