@@ -25,6 +25,7 @@
  *		\brief      File with parent class of submodules to manage numbering and document generation
  */
 require_once DOL_DOCUMENT_ROOT.'/core/class/commondocgenerator.class.php';
+require_once DOL_DOCUMENT_ROOT.'/core/class/commonnumrefgenerator.class.php';
 
 
 /**
@@ -32,11 +33,6 @@ require_once DOL_DOCUMENT_ROOT.'/core/class/commondocgenerator.class.php';
  */
 abstract class ModeleThirdPartyDoc extends CommonDocGenerator
 {
-	/**
-	 * @var string Error code (or message)
-	 */
-	public $error = '';
-
 	// phpcs:disable PEAR.NamingConventions.ValidFunctionName.ScopeNotCamelCaps
 	/**
 	 *  Return list of active generation modules
@@ -48,7 +44,6 @@ abstract class ModeleThirdPartyDoc extends CommonDocGenerator
 	public static function liste_modeles($dbs, $maxfilenamelength = 0)
 	{
 		// phpcs:enable
-
 		$type = 'company';
 		$list = array();
 
@@ -62,62 +57,25 @@ abstract class ModeleThirdPartyDoc extends CommonDocGenerator
 /**
  *		Parent class for third parties code generators
  */
-abstract class ModeleThirdPartyCode
+abstract class ModeleThirdPartyCode extends CommonNumRefGenerator
 {
 	/**
-	 * @var string Error code (or message)
+	 * @var int Automatic numbering
 	 */
-	public $error = '';
+	public $code_auto;
 
 	/**
-	 * @var array Error code (or message) array
+	 * @var string Editable code
 	 */
-	public $errors;
+	public $code_modifiable;
 
-
-	/**     Renvoi la description par defaut du modele de numerotation
-	 *
-	 *		@param	Translate	$langs		Object langs
-	 *      @return string      			Texte descripif
-	 */
-	public function info($langs)
-	{
-		$langs->load("bills");
-		return $langs->trans("NoDescription");
-	}
-
-	/**     Return name of module
-	 *
-	 *		@param	Translate	$langs		Object langs
-	 *      @return string      			Nom du module
-	 */
-	public function getNom($langs)
-	{
-		return $this->name;
-	}
-
-
-	/**     Return an example of numbering
-	 *
-	 *		@param	Translate	$langs		Object langs
-	 *      @return string      			Example
-	 */
-	public function getExample($langs)
-	{
-		$langs->load("bills");
-		return $langs->trans("NoExample");
-	}
+	public $code_modifiable_invalide; // Modified code if it is invalid
 
 	/**
-	 *  Checks if the numbers already in the database do not
-	 *  cause conflicts that would prevent this numbering working.
-	 *
-	 *  @return     boolean     false if conflict, true if ok
+	 * @var int Code facultatif
 	 */
-	public function canBeActivated()
-	{
-		return true;
-	}
+	public $code_null;
+
 
 	/**
 	 *  Return next value available
@@ -132,30 +90,6 @@ abstract class ModeleThirdPartyCode
 		return $langs->trans("Function_getNextValue_InModuleNotWorking");
 	}
 
-
-	/**
-	 *  Return version of module
-	 *
-	 *  @return     string      Version
-	 */
-	public function getVersion()
-	{
-		global $langs;
-		$langs->load("admin");
-
-		if ($this->version == 'development') {
-			return $langs->trans("VersionDevelopment");
-		} elseif ($this->version == 'experimental') {
-			return $langs->trans("VersionExperimental");
-		} elseif ($this->version == 'dolibarr') {
-			return DOL_VERSION;
-		} elseif ($this->version) {
-			return $this->version;
-		} else {
-			return $langs->trans("NotAvailable");
-		}
-	}
-
 	// phpcs:disable PEAR.NamingConventions.ValidFunctionName.ScopeNotCamelCaps
 	/**
 	 *  Renvoie la liste des modeles de numérotation
@@ -201,7 +135,7 @@ abstract class ModeleThirdPartyCode
 
 		$strikestart = '';
 		$strikeend = '';
-		if (!empty($conf->global->MAIN_COMPANY_CODE_ALWAYS_REQUIRED) && !empty($this->code_null)) {
+		if (getDolGlobalString('MAIN_COMPANY_CODE_ALWAYS_REQUIRED') && !empty($this->code_null)) {
 			$strikestart = '<strike>';
 			$strikeend = '</strike> '.yn(1, 1, 2).' ('.$langs->trans("ForcedToByAModule", $langs->transnoentities("yes")).')';
 		}
@@ -274,73 +208,12 @@ abstract class ModeleThirdPartyCode
 /**
  *		Parent class for third parties accountancy code generators
  */
-abstract class ModeleAccountancyCode
+abstract class ModeleAccountancyCode extends CommonNumRefGenerator
 {
 	/**
-	 * @var string Error code (or message)
+	 * @var string
 	 */
-	public $error = '';
-
-
-	/**
-	 *  Return description of module
-	 *
-	 *  @param	Translate	$langs		Object langs
-	 *  @return string      			Description of module
-	 */
-	public function info($langs)
-	{
-		$langs->load("bills");
-		return $langs->trans("NoDescription");
-	}
-
-	/**
-	 *  Return an example of result returned by getNextValue
-	 *
-	 *  @param	Translate	$langs		Object langs
-	 *  @param	societe		$objsoc		Object thirdparty
-	 *  @param	int			$type		Type of third party (1:customer, 2:supplier, -1:autodetect)
-	 *  @return	string					Example
-	 */
-	public function getExample($langs, $objsoc = 0, $type = -1)
-	{
-		$langs->load("bills");
-		return $langs->trans("NoExample");
-	}
-
-	/**
-	 *  Checks if the numbers already in the database do not
-	 *  cause conflicts that would prevent this numbering working.
-	 *
-	 *  @return     boolean     false if conflict, true if ok
-	 */
-	public function canBeActivated()
-	{
-		return true;
-	}
-
-	/**
-	 *  Return version of module
-	 *
-	 *  @return     string      Version
-	 */
-	public function getVersion()
-	{
-		global $langs;
-		$langs->load("admin");
-
-		if ($this->version == 'development') {
-			return $langs->trans("VersionDevelopment");
-		} elseif ($this->version == 'experimental') {
-			return $langs->trans("VersionExperimental");
-		} elseif ($this->version == 'dolibarr') {
-			return DOL_VERSION;
-		} elseif ($this->version) {
-			return $this->version;
-		} else {
-			return $langs->trans("NotAvailable");
-		}
-	}
+	public $code;
 
 	/**
 	 *  Return description of module parameters
@@ -352,7 +225,7 @@ abstract class ModeleAccountancyCode
 	 */
 	public function getToolTip($langs, $soc, $type)
 	{
-		global $conf, $db;
+		global $db;
 
 		$langs->load("admin");
 
