@@ -32,31 +32,31 @@ include 'inc.php';
 
 global $langs;
 
-$action = GETPOST('action', 'aZ09') ?GETPOST('action', 'aZ09') : (empty($argv[1]) ? '' : $argv[1]);
-$setuplang = GETPOST('selectlang', 'aZ09', 3) ?GETPOST('selectlang', 'aZ09', 3) : (empty($argv[2]) ? 'auto' : $argv[2]);
+$action = GETPOST('action', 'aZ09') ? GETPOST('action', 'aZ09') : (empty($argv[1]) ? '' : $argv[1]);
+$setuplang = GETPOST('selectlang', 'aZ09', 3) ? GETPOST('selectlang', 'aZ09', 3) : (empty($argv[2]) ? 'auto' : $argv[2]);
 $langs->setDefaultLang($setuplang);
 
 $langs->loadLangs(array("admin", "install", "errors"));
 
 // Dolibarr pages directory
-$main_dir = GETPOST('main_dir') ?GETPOST('main_dir') : (empty($argv[3]) ? '' : $argv[3]);
+$main_dir = GETPOST('main_dir') ? GETPOST('main_dir') : (empty($argv[3]) ? '' : $argv[3]);
 // Directory for generated documents (invoices, orders, ecm, etc...)
 $main_data_dir = GETPOST('main_data_dir') ? GETPOST('main_data_dir') : (empty($argv[4]) ? ($main_dir.'/documents') : $argv[4]);
 // Dolibarr root URL
-$main_url = GETPOST('main_url') ?GETPOST('main_url') : (empty($argv[5]) ? '' : $argv[5]);
+$main_url = GETPOST('main_url') ? GETPOST('main_url') : (empty($argv[5]) ? '' : $argv[5]);
 // Database login information
-$userroot = GETPOST('db_user_root', 'alpha') ?GETPOST('db_user_root', 'alpha') : (empty($argv[6]) ? '' : $argv[6]);
-$passroot = GETPOST('db_pass_root', 'none') ?GETPOST('db_pass_root', 'none') : (empty($argv[7]) ? '' : $argv[7]);
+$userroot = GETPOST('db_user_root', 'alpha') ? GETPOST('db_user_root', 'alpha') : (empty($argv[6]) ? '' : $argv[6]);
+$passroot = GETPOST('db_pass_root', 'none') ? GETPOST('db_pass_root', 'none') : (empty($argv[7]) ? '' : $argv[7]);
 // Database server
-$db_type = GETPOST('db_type', 'aZ09') ?GETPOST('db_type', 'aZ09') : (empty($argv[8]) ? '' : $argv[8]);
-$db_host = GETPOST('db_host', 'alpha') ?GETPOST('db_host', 'alpha') : (empty($argv[9]) ? '' : $argv[9]);
-$db_name = GETPOST('db_name', 'aZ09') ?GETPOST('db_name', 'aZ09') : (empty($argv[10]) ? '' : $argv[10]);
-$db_user = GETPOST('db_user', 'alpha') ?GETPOST('db_user', 'alpha') : (empty($argv[11]) ? '' : $argv[11]);
-$db_pass = GETPOST('db_pass', 'none') ?GETPOST('db_pass', 'none') : (empty($argv[12]) ? '' : $argv[12]);
-$db_port = GETPOST('db_port', 'int') ?GETPOST('db_port', 'int') : (empty($argv[13]) ? '' : $argv[13]);
-$db_prefix = GETPOST('db_prefix', 'aZ09') ?GETPOST('db_prefix', 'aZ09') : (empty($argv[14]) ? '' : $argv[14]);
-$db_create_database = GETPOST('db_create_database', 'alpha') ?GETPOST('db_create_database', 'alpha') : (empty($argv[15]) ? '' : $argv[15]);
-$db_create_user = GETPOST('db_create_user', 'alpha') ?GETPOST('db_create_user', 'alpha') : (empty($argv[16]) ? '' : $argv[16]);
+$db_type = GETPOST('db_type', 'aZ09') ? GETPOST('db_type', 'aZ09') : (empty($argv[8]) ? '' : $argv[8]);
+$db_host = GETPOST('db_host', 'alpha') ? GETPOST('db_host', 'alpha') : (empty($argv[9]) ? '' : $argv[9]);
+$db_name = GETPOST('db_name', 'aZ09') ? GETPOST('db_name', 'aZ09') : (empty($argv[10]) ? '' : $argv[10]);
+$db_user = GETPOST('db_user', 'alpha') ? GETPOST('db_user', 'alpha') : (empty($argv[11]) ? '' : $argv[11]);
+$db_pass = GETPOST('db_pass', 'none') ? GETPOST('db_pass', 'none') : (empty($argv[12]) ? '' : $argv[12]);
+$db_port = GETPOST('db_port', 'int') ? GETPOST('db_port', 'int') : (empty($argv[13]) ? '' : $argv[13]);
+$db_prefix = GETPOST('db_prefix', 'aZ09') ? GETPOST('db_prefix', 'aZ09') : (empty($argv[14]) ? '' : $argv[14]);
+$db_create_database = GETPOST('db_create_database', 'alpha') ? GETPOST('db_create_database', 'alpha') : (empty($argv[15]) ? '' : $argv[15]);
+$db_create_user = GETPOST('db_create_user', 'alpha') ? GETPOST('db_create_user', 'alpha') : (empty($argv[16]) ? '' : $argv[16]);
 // Force https
 $main_force_https = ((GETPOST("main_force_https", 'alpha') && (GETPOST("main_force_https", 'alpha') == "on" || GETPOST("main_force_https", 'alpha') == 1)) ? '1' : '0');
 // Use alternative directory
@@ -84,22 +84,34 @@ if (@file_exists($forcedfile)) {
 	// If forced install is enabled, replace the post values. These are empty because form fields are disabled.
 	if ($force_install_noedit) {
 		$main_dir = detect_dolibarr_main_document_root();
-		if (!empty($argv[1])) {
-			$main_dir = $argv[1]; // override when executing the script in command line
+		if (!empty($argv[3])) {
+			$main_dir = $argv[3]; // override when executing the script in command line
 		}
 		if (!empty($force_install_main_data_root)) {
 			$main_data_dir = $force_install_main_data_root;
 		} else {
 			$main_data_dir = detect_dolibarr_main_data_root($main_dir);
 		}
+		if (!empty($argv[4])) {
+			$main_data_dir = $argv[4]; // override when executing the script in command line
+		}
 		$main_url = detect_dolibarr_main_url_root();
+		if (!empty($argv[5])) {
+			$main_url = $argv[5]; // override when executing the script in command line
+		}
 
 		if (!empty($force_install_databaserootlogin)) {
 			$userroot = parse_database_login($force_install_databaserootlogin);
 		}
+		if (!empty($argv[6])) {
+			$userroot = $argv[6]; // override when executing the script in command line
+		}
 		if (!empty($force_install_databaserootpass)) {
 			$passroot = parse_database_pass($force_install_databaserootpass);
 		}
+		if (!empty($argv[7])) {
+			$passroot = $argv[7]; // override when executing the script in command line
+		}
 	}
 	if ($force_install_noedit == 2) {
 		if (!empty($force_install_type)) {
@@ -240,7 +252,7 @@ if (!$error) {
 				}
 			}
 
-			$db = getDoliDBInstance($db_type, $db_host, $userroot, $passroot, $databasefortest, $db_port);
+			$db = getDoliDBInstance($db_type, $db_host, $userroot, $passroot, $databasefortest, (int) $db_port);
 
 			dol_syslog("databasefortest=".$databasefortest." connected=".$db->connected." database_selected=".$db->database_selected, LOG_DEBUG);
 			//print "databasefortest=".$databasefortest." connected=".$db->connected." database_selected=".$db->database_selected;
@@ -272,7 +284,7 @@ if (!$error) {
 
 		// If we need simple access
 		if (!$error && (empty($db_create_database) && empty($db_create_user))) {
-			$db = getDoliDBInstance($db_type, $db_host, $db_user, $db_pass, $db_name, $db_port);
+			$db = getDoliDBInstance($db_type, $db_host, $db_user, $db_pass, $db_name, (int) $db_port);
 
 			if ($db->error) {
 				print '<div class="error">'.$db->error.'</div>';
@@ -323,12 +335,16 @@ if (!$error && $db->connected) {
 
 		$defaultCharacterSet = $db->forcecharset;
 		$defaultDBSortingCollation = $db->forcecollate;
-	} else // If already created, we take current value
-	{
+	} else { // If already created, we take current value
 		$defaultCharacterSet = $db->getDefaultCharacterSetDatabase();
 		$defaultDBSortingCollation = $db->getDefaultCollationDatabase();
 	}
 
+	// It seems some PHP driver mysqli does not support utf8mb3
+	if ($defaultCharacterSet == 'utf8mb3' || $defaultDBSortingCollation == 'utf8mb3_unicode_ci') {
+		$defaultCharacterSet = 'utf8';
+		$defaultDBSortingCollation = 'utf8_unicode_ci';
+	}
 	// Force to avoid utf8mb4 because index on field char 255 reach limit of 767 char for indexes (example with mysql 5.6.34 = mariadb 10.0.29)
 	// TODO Remove this when utf8mb4 is supported
 	if ($defaultCharacterSet == 'utf8mb4' || $defaultDBSortingCollation == 'utf8mb4_unicode_ci') {
@@ -529,7 +545,7 @@ if (!$error && $db->connected && $action == "set") {
 
 			// Check database connection
 
-			$db = getDoliDBInstance($conf->db->type, $conf->db->host, $userroot, $passroot, $databasefortest, $conf->db->port);
+			$db = getDoliDBInstance($conf->db->type, $conf->db->host, $userroot, $passroot, $databasefortest, (int) $conf->db->port);
 
 			if ($db->error) {
 				print '<div class="error">'.$db->error.'</div>';
@@ -566,8 +582,8 @@ if (!$error && $db->connected && $action == "set") {
 							print '<td><img src="../theme/eldy/img/tick.png" alt="Ok"></td></tr>';
 						} else {
 							if ($db->errno() == 'DB_ERROR_RECORD_ALREADY_EXISTS'
-							|| $db->errno() == 'DB_ERROR_KEY_NAME_ALREADY_EXISTS'
-							|| $db->errno() == 'DB_ERROR_USER_ALREADY_EXISTS') {
+								|| $db->errno() == 'DB_ERROR_KEY_NAME_ALREADY_EXISTS'
+								|| $db->errno() == 'DB_ERROR_USER_ALREADY_EXISTS') {
 								dolibarr_install_syslog("step1: user already exists");
 								print '<tr><td>';
 								print $langs->trans("UserCreation").' : ';
@@ -611,7 +627,7 @@ if (!$error && $db->connected && $action == "set") {
 		// If database creation was asked, we create it
 		if (!$error && (isset($db_create_database) && ($db_create_database == "1" || $db_create_database == "on"))) {
 			dolibarr_install_syslog("step1: create database: ".$dolibarr_main_db_name." ".$dolibarr_main_db_character_set." ".$dolibarr_main_db_collation." ".$dolibarr_main_db_user);
-			$newdb = getDoliDBInstance($conf->db->type, $conf->db->host, $userroot, $passroot, '', $conf->db->port);
+			$newdb = getDoliDBInstance($conf->db->type, $conf->db->host, $userroot, $passroot, '', (int) $conf->db->port);
 			//print 'eee'.$conf->db->type." ".$conf->db->host." ".$userroot." ".$passroot." ".$conf->db->port." ".$newdb->connected." ".$newdb->forcecharset;exit;
 
 			if ($newdb->connected) {
@@ -671,7 +687,7 @@ if (!$error && $db->connected && $action == "set") {
 			dolibarr_install_syslog("step1: connection type=".$conf->db->type." on host=".$conf->db->host." port=".$conf->db->port." user=".$conf->db->user." name=".$conf->db->name);
 			//print "connexion de type=".$conf->db->type." sur host=".$conf->db->host." port=".$conf->db->port." user=".$conf->db->user." name=".$conf->db->name;
 
-			$db = getDoliDBInstance($conf->db->type, $conf->db->host, $conf->db->user, $conf->db->pass, $conf->db->name, $conf->db->port);
+			$db = getDoliDBInstance($conf->db->type, $conf->db->host, $conf->db->user, $conf->db->pass, $conf->db->name, (int) $conf->db->port);
 
 			if ($db->connected) {
 				dolibarr_install_syslog("step1: connection to server by user ".$conf->db->user." ok");
@@ -908,7 +924,7 @@ function write_conf_file($conffile)
 		fputs($fp, '$dolibarr_main_force_https=\''.$main_force_https.'\';');
 		fputs($fp, "\n");
 
-		fputs($fp, '$dolibarr_main_restrict_os_commands=\'mysqldump, mysql, pg_dump, pgrestore\';');
+		fputs($fp, '$dolibarr_main_restrict_os_commands=\'mariadb-dump, mariadb, mysqldump, mysql, pg_dump, pgrestore, clamdscan, clamscan.exe\';');
 		fputs($fp, "\n");
 
 		fputs($fp, '$dolibarr_nocsrfcheck=\'0\';');
@@ -925,57 +941,68 @@ function write_conf_file($conffile)
 		// Write params to overwrites default lib path
 		fputs($fp, "\n");
 		if (empty($force_dolibarr_lib_FPDF_PATH)) {
-			fputs($fp, '//'); $force_dolibarr_lib_FPDF_PATH = '';
+			fputs($fp, '//');
+			$force_dolibarr_lib_FPDF_PATH = '';
 		}
 		fputs($fp, '$dolibarr_lib_FPDF_PATH=\''.$force_dolibarr_lib_FPDF_PATH.'\';');
 		fputs($fp, "\n");
 		if (empty($force_dolibarr_lib_TCPDF_PATH)) {
-			fputs($fp, '//'); $force_dolibarr_lib_TCPDF_PATH = '';
+			fputs($fp, '//');
+			$force_dolibarr_lib_TCPDF_PATH = '';
 		}
 		fputs($fp, '$dolibarr_lib_TCPDF_PATH=\''.$force_dolibarr_lib_TCPDF_PATH.'\';');
 		fputs($fp, "\n");
 		if (empty($force_dolibarr_lib_FPDI_PATH)) {
-			fputs($fp, '//'); $force_dolibarr_lib_FPDI_PATH = '';
+			fputs($fp, '//');
+			$force_dolibarr_lib_FPDI_PATH = '';
 		}
 		fputs($fp, '$dolibarr_lib_FPDI_PATH=\''.$force_dolibarr_lib_FPDI_PATH.'\';');
 		fputs($fp, "\n");
 		if (empty($force_dolibarr_lib_TCPDI_PATH)) {
-			fputs($fp, '//'); $force_dolibarr_lib_TCPDI_PATH = '';
+			fputs($fp, '//');
+			$force_dolibarr_lib_TCPDI_PATH = '';
 		}
 		fputs($fp, '$dolibarr_lib_TCPDI_PATH=\''.$force_dolibarr_lib_TCPDI_PATH.'\';');
 		fputs($fp, "\n");
 		if (empty($force_dolibarr_lib_GEOIP_PATH)) {
-			fputs($fp, '//'); $force_dolibarr_lib_GEOIP_PATH = '';
+			fputs($fp, '//');
+			$force_dolibarr_lib_GEOIP_PATH = '';
 		}
 		fputs($fp, '$dolibarr_lib_GEOIP_PATH=\''.$force_dolibarr_lib_GEOIP_PATH.'\';');
 		fputs($fp, "\n");
 		if (empty($force_dolibarr_lib_NUSOAP_PATH)) {
-			fputs($fp, '//'); $force_dolibarr_lib_NUSOAP_PATH = '';
+			fputs($fp, '//');
+			$force_dolibarr_lib_NUSOAP_PATH = '';
 		}
 		fputs($fp, '$dolibarr_lib_NUSOAP_PATH=\''.$force_dolibarr_lib_NUSOAP_PATH.'\';');
 		fputs($fp, "\n");
 		if (empty($force_dolibarr_lib_ODTPHP_PATH)) {
-			fputs($fp, '//'); $force_dolibarr_lib_ODTPHP_PATH = '';
+			fputs($fp, '//');
+			$force_dolibarr_lib_ODTPHP_PATH = '';
 		}
 		fputs($fp, '$dolibarr_lib_ODTPHP_PATH=\''.$force_dolibarr_lib_ODTPHP_PATH.'\';');
 		fputs($fp, "\n");
 		if (empty($force_dolibarr_lib_ODTPHP_PATHTOPCLZIP)) {
-			fputs($fp, '//'); $force_dolibarr_lib_ODTPHP_PATHTOPCLZIP = '';
+			fputs($fp, '//');
+			$force_dolibarr_lib_ODTPHP_PATHTOPCLZIP = '';
 		}
 		fputs($fp, '$dolibarr_lib_ODTPHP_PATHTOPCLZIP=\''.$force_dolibarr_lib_ODTPHP_PATHTOPCLZIP.'\';');
 		fputs($fp, "\n");
 		if (empty($force_dolibarr_js_CKEDITOR)) {
-			fputs($fp, '//'); $force_dolibarr_js_CKEDITOR = '';
+			fputs($fp, '//');
+			$force_dolibarr_js_CKEDITOR = '';
 		}
 		fputs($fp, '$dolibarr_js_CKEDITOR=\''.$force_dolibarr_js_CKEDITOR.'\';');
 		fputs($fp, "\n");
 		if (empty($force_dolibarr_js_JQUERY)) {
-			fputs($fp, '//'); $force_dolibarr_js_JQUERY = '';
+			fputs($fp, '//');
+			$force_dolibarr_js_JQUERY = '';
 		}
 		fputs($fp, '$dolibarr_js_JQUERY=\''.$force_dolibarr_js_JQUERY.'\';');
 		fputs($fp, "\n");
 		if (empty($force_dolibarr_js_JQUERY_UI)) {
-			fputs($fp, '//'); $force_dolibarr_js_JQUERY_UI = '';
+			fputs($fp, '//');
+			$force_dolibarr_js_JQUERY_UI = '';
 		}
 		fputs($fp, '$dolibarr_js_JQUERY_UI=\''.$force_dolibarr_js_JQUERY_UI.'\';');
 		fputs($fp, "\n");
@@ -983,12 +1010,14 @@ function write_conf_file($conffile)
 		// Write params to overwrites default font path
 		fputs($fp, "\n");
 		if (empty($force_dolibarr_font_DOL_DEFAULT_TTF)) {
-			fputs($fp, '//'); $force_dolibarr_font_DOL_DEFAULT_TTF = '';
+			fputs($fp, '//');
+			$force_dolibarr_font_DOL_DEFAULT_TTF = '';
 		}
 		fputs($fp, '$dolibarr_font_DOL_DEFAULT_TTF=\''.$force_dolibarr_font_DOL_DEFAULT_TTF.'\';');
 		fputs($fp, "\n");
 		if (empty($force_dolibarr_font_DOL_DEFAULT_TTF_BOLD)) {
-			fputs($fp, '//'); $force_dolibarr_font_DOL_DEFAULT_TTF_BOLD = '';
+			fputs($fp, '//');
+			$force_dolibarr_font_DOL_DEFAULT_TTF_BOLD = '';
 		}
 		fputs($fp, '$dolibarr_font_DOL_DEFAULT_TTF_BOLD=\''.$force_dolibarr_font_DOL_DEFAULT_TTF_BOLD.'\';');
 		fputs($fp, "\n");
